@@ -81,7 +81,7 @@ def setup(**settings_patches):
                     # Build and install
                     local('python uwsgiconfig.py --build beanstalk')
                     local('cp uwsgi /usr/local/bin/uwsgi')
-                    if not os.path.exists('/usr/bin/uwsgi'):
+                    if os.path.exists('/usr/bin/uwsgi'):
                         local('ln -s /usr/local/bin/uwsgi /usr/bin/uwsgi')
                     # mod_uwsgi
                     local('apxs -i -c apache2/mod_uwsgi.c')
@@ -154,7 +154,7 @@ def setup(**settings_patches):
         'Match Group beanstalk',
         '       ForceCommand /usr/bin/bs_ssh_entry',
     ]
-    local(sed('$a\\\n{command}'.format(command='\\\n'.join(new_lines)), sshd_config))
+    local(sed('$ a\\\n{command}'.format(command='\\n'.join(new_lines)), sshd_config))
     local(sed('s/^AllowGroups (.*)$/AllowGroups \\1 beanstalk/g', sshd_config, '-E'))
 
     # Apache conf
